eqcorrscan.core.match\_filter.helpers.extract\_from\_stream
===========================================================

.. currentmodule:: eqcorrscan.core.match_filter.helpers

.. autofunction:: extract_from_stream